Set-ExecutionPolicy Unrestricted -Scope CurrentUser
function Invoke-Sqlcmd2
{
    param(
    [string]$ServerInstance,
    [string]$Database,
    [string]$Query,
    [Int32]$QueryTimeout=30
    )
 
    $conn=new-object System.Data.SqlClient.SQLConnection
    $conn.ConnectionString="Server={0};Database={1};Integrated Security=True" -f $ServerInstance,$Database
    $conn.Open()
    $cmd=new-object system.Data.SqlClient.SqlCommand($Query,$conn)
    $cmd.CommandTimeout=$QueryTimeout
    $ds=New-Object system.Data.DataSet
    $da=New-Object system.Data.SqlClient.SqlDataAdapter($cmd)
    [void]$da.fill($ds)
    $conn.Close()
    $ds.Tables[0]
 
}
$MyResults=@()
$backupquery = @"
SELECT @@ServerName AS [HostName], sj.name AS Job_Name, sjh.step_name AS Job_Step_Name, 
CASE
WHEN CHARINDEX('\', @@ServerName) = 0 THEN 'MSSQLSERVER'
WHEN CHARINDEX('\', @@ServerName) <> 0 THEN SUBSTRING(@@ServerName, CHARINDEX('\', @@ServerName)+1, LEN(@@ServerName))
END
AS [InstanceName], 'NA' AS [DatabaseName], --convert(varchar(20), sjh.run_date, 101), 
substring(convert(varchar(20),sjh.run_date),7,2) + '/' +
substring(convert(varchar(20),sjh.run_date),5,2) + '/' +
substring(convert(varchar(20),sjh.run_date),1,4)
+ ' ' + 
CASE
WHEN Len(convert(varchar(20),sjh.run_time)) = 6 THEN substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2)+':'+substring(convert(varchar(20),sjh.run_time),5,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 5 THEN '0' + substring(convert(varchar(20),sjh.run_time),1,1)+':'+substring(convert(varchar(20),sjh.run_time),2,2)+':'+substring(convert(varchar(20),sjh.run_time),4,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 4 THEN '00' +':'+ substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2) 
END

AS [StartTime],  'NA' AS [EndTime], 'NA' AS[Level], 
CASE
WHEN sjh.run_status = 0 THEN 'failed'
WHEN sjh.run_status <> 0 THEN 'success'
END AS [Status]
, 'NA' AS [SizeOfBackup],
substring(convert(varchar(20),sjh.run_date),7,2) + '/' +
substring(convert(varchar(20),sjh.run_date),5,2) + '/' +
substring(convert(varchar(20),sjh.run_date),1,4)
+ ' ' + 
CASE
WHEN Len(convert(varchar(20),sjh.run_time)) = 6 THEN substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2)+':'+substring(convert(varchar(20),sjh.run_time),5,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 5 THEN '0' + substring(convert(varchar(20),sjh.run_time),1,1)+':'+substring(convert(varchar(20),sjh.run_time),2,2)+':'+substring(convert(varchar(20),sjh.run_time),4,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 4 THEN '00' +':'+ substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2)
END 

AS [QueueTime]
, 'SQL_SERVER' AS [GroupName]
FROM [msdb].[dbo].[sysjobhistory] sjh, msdb.dbo.sysjobs sj 
  where sjh.job_id = sj.job_id
  --AND  (sjh.step_name like '%Backup%' or sj.name like '%Backup%')
  AND (sjh.step_id <> 0 AND run_status = 0)
  AND convert(datetime, convert(varchar(20),sjh.run_date)
+' '+
CASE
WHEN Len(convert(varchar(20),sjh.run_time)) = 6 THEN substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2)+':'+substring(convert(varchar(20),sjh.run_time),5,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 5 THEN '0' + substring(convert(varchar(20),sjh.run_time),1,1)+':'+substring(convert(varchar(20),sjh.run_time),2,2)+':'+substring(convert(varchar(20),sjh.run_time),4,2)
WHEN Len(convert(varchar(20),sjh.run_time)) = 4 THEN '00' +':'+ substring(convert(varchar(20),sjh.run_time),1,2)+':'+substring(convert(varchar(20),sjh.run_time),3,2)
END, 101) > getdate()-1
"@
try
{
foreach ($server in (Get-Content G:\SQLPASS-Summit2014\DBANotification\myservers.txt))
{   $MyResults += Invoke-Sqlcmd2  $server msdb $backupquery 60 } 
 $MyResults  | Where-Object {$_} | Export-Csv G:\SQLPASS-Summit2014\DBANotification\SSFailedJobs.csv -NoTypeInformation
 (Get-Content  G:\SQLPASS-Summit2014\DBANotification\SSFailedJobs.csv) | % {$_ -replace '"', ""} | % {$_ -replace '#', '"'} | out-file -FilePath G:\SQLPASS-Summit2014\DBANotification\UnquotedSSFailedJobs.csv
}
catch
{
        write-host $server
        write-host "Caught an exception:" -ForegroundColor Red
        write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
        write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
        write-host $server.server_name -ForegroundColor Red
}
finally
{
        write-host "Finally completed."
}
exit